@@ -1,6 +1,6 @@
 package Koha::Contrib::Sudoc::Converter;
 # ABSTRACT: Classe de base pour convertir les notices
-$Koha::Contrib::Sudoc::Converter::VERSION = '2.09';
+$Koha::Contrib::Sudoc::Converter::VERSION = '2.10';
 use Moose;
 use Modern::Perl;
 
@@ -43,7 +43,9 @@ sub init {
     # On supprime de la notice SUDOC les champs à exclure
     my $exclure = $self->sudoc->c->{biblio}->{exclure};
     if ( $exclure && ref($exclure) eq 'ARRAY' ) {
-        $record->fields( [ grep { not $_->tag ~~ @$exclure } @{$record->fields} ] );
+        my %hexclure;
+        $hexclure{$_} = 1 for @$exclure;
+        $record->fields( [ grep { not $hexclure{$_->tag} } @{$record->fields} ] );
     }
 }
 
@@ -204,7 +206,7 @@ Koha::Contrib::Sudoc::Converter - Classe de base pour convertir les notices
 
 =head1 VERSION
 
-version 2.09
+version 2.10
 
 =head1 DESCRIPTION
 
